### Getting Started

PyDM offers a great step-by-step [tutorial](https://slaclab.github.io/pydm-tutorial)
with detailed information to help you get started with creating displays and even
more complex applications. 

### Bug reports & Feature request

If you spot a problem with PyDM, please let us know by following the template in
here: [Report a bug](https://github.com/slaclab/pydm/issues/new?template=bug-report.md).

Ideas or suggestions for enhancements are more than welcome. Please use the following
template in here: [Request feature](https://github.com/slaclab/pydm/issues/new?template=feature-request.md).

### Contact us

If you have questions of comments in general about PyDM we want to know.

You can choose between the channels open for communication the one that best fit you:

- Chat channel using [Gitter](<https://gitter.im/pydm/General>) (Public)
- Stanford & SLAC [Slack channel](<https://slac.slack.com/messages/C6B8GRCPQ>) (Limited for users with a Stanford Account)
- PyDM [Mailing List](https://listserv.slac.stanford.edu/cgi-bin/wa?SUBED1=PYDM-USERS) (Limited for SLAC users for now)

or you can [file a bug](https://github.com/slaclab/pydm/issues/new?template=bug-report.md) and let us know where our documentation could be improved.